import { Component, OnInit } from '@angular/core';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';


export interface PeriodicElement {
  id: number;
  title: string;
  has_prefix: boolean;
  has_main: boolean;
  has_suffix: boolean;
}
const ELEMENT_DATA: PeriodicElement[] = [{id: 5, title:"ss", has_prefix: false, has_main:true, has_suffix:true},
{id: 6, title:"s222s", has_prefix: false, has_main:true, has_suffix:true}];

@Component({
  selector: 'app-boilerplate-list',
  templateUrl: './boilerplate-list.component.html',
  styleUrls: ['./boilerplate-list.component.scss']
})

export class BoilerplateListComponent implements OnInit {

  boilerplates?: Boilerplate[];
  currentBoilerplate?: Boilerplate;
  currentIndex = -1;
  title = '';
  displayedColumns: string[] = ['id', 'title', 'has_prefix', 'has_main', 'has_suffix'];
  dataSource = [{}]; //ELEMENT_DATA;
  
  constructor(private boilerplateService: BoilerplateService) { }

  ngOnInit(): void {
    this.retrieveBoilerplates();
  }

  retrieveBoilerplates(): void {
    this.dataSource = [{}];
    this.boilerplateService.getAll()
      .subscribe(
        data => {
          this.boilerplates = data;
          //this.boilerplates = this.dataSource;
          data.forEach(val => this.dataSource.push(Object.assign(val)));
          console.log(this.dataSource);
        },
        error => {
          console.log(error);
        });
  }

  refreshList(): void {
    this.retrieveBoilerplates();
    this.currentBoilerplate = undefined;
    this.currentIndex = -1;
  }

  setActiveBoilerplate(boilerplate: Boilerplate, index: number): void {
    this.currentBoilerplate = boilerplate;
    this.currentIndex = index;
  }


  SearchTitle(): void {
    if (this.title != ''){
      this.boilerplateService.findByTitle(this.title)
        .subscribe(
          data => {
            this.boilerplates = data;
            console.log(data);
          },
          error => {
            console.log(error);
          });

  } 
    else {
      this.retrieveBoilerplates();
    }
  }

}
